@@ -1,7 +1,6 @@
 ;;; pspp-mode-el -- Major mode for editing PSPP files
 
 ;; Copyright (C) 2005 Free Software Foundation
-;; Author: John Darrington <john@darrington.wattle.id.au>
 ;; Created: 05 March 2005
 ;; Keywords: PSPP major-mode
 
@@ -12,20 +11,18 @@
 
 ;; Copyright (C) 2000, 2003 Scott Andrew Borton <scott@pp.htv.fi>
 
-;; This program is free software; you can redistribute it and/or
-;; modify it under the terms of the GNU General Public License as
-;; published by the Free Software Foundation; either version 3 of
-;; the License, or (at your option) any later version.
-
-;; This program is distributed in the hope that it will be
-;; useful, but WITHOUT ANY WARRANTY; without even the implied
-;; warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-;; PURPOSE.  See the GNU General Public License for more details.
-
-;; You should have received a copy of the GNU General Public
-;; License along with this program; if not, write to the Free
-;; Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-;; MA 02110-1301 USA
+;; This program is free software: you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation, either version 3 of the License, or
+;; (at your option) any later version.
+;; 
+;; This program is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 ;;; Code:
 (defvar pspp-mode-hook nil)
@@ -389,7 +386,6 @@
 				"PRINT FORMATS"          
 				"PRINT SPACE"            
 				"PROCEDURE OUTPUT"       
-				"PROCESS IF"             
 				"PROXIMITIES"            
 				"Q"                      
 				"QUICK CLUSTER"          
