@@ -20,7 +20,6 @@
 
 #include <ctype.h>
 #include <float.h>
-#include <gsl/gsl_math.h>
 #include <math.h>
 #include <stdint.h>
 #include <stdlib.h>
@@ -928,9 +927,9 @@ output_infinite (double number, const struct fmt_spec *format, char *output)
     {
       const char *s;
 
-      if (gsl_isnan (number))
+      if (isnan (number))
         s = "NaN";
-      else if (gsl_isinf (number))
+      else if (isinf (number))
         s = number > 0 ? "+Infinity" : "-Infinity";
       else
         s = "Unknown";
