@@ -41,7 +41,6 @@
 
 #include <gsl/gsl_cdf.h>
 #include <gsl/gsl_randist.h>
-#include <gsl-extras/gsl-extras.h>
 
 #include <minmax.h>
 
@@ -79,7 +78,7 @@ calculate_binomial_internal (double n1, double n2, double p)
   /* SPSS Statistical Algorithms has completely different and WRONG
      advice here. */
 
-  double sig1tailed = gslextras_cdf_binomial_P (n1, n1 + n2, p);
+  double sig1tailed = gsl_cdf_binomial_P (n1, p, n1 + n2);
 
   if ( p == 0.5 )
     return sig1tailed > 0.5 ? 1.0 :sig1tailed * 2.0;
