@@ -5,20 +5,30 @@
 
 TEMPDIR=/tmp/pspp-tst-$$
 
-here=`pwd`;
+# ensure that top_builddir  are absolute
+if [ -z "$top_builddir" ] ; then top_builddir=. ; fi
+if [ -z "$top_srcdir" ] ; then top_srcdir=. ; fi
+top_builddir=`cd $top_builddir; pwd`
+PSPP=$top_builddir/src/ui/terminal/pspp
 
 # ensure that top_srcdir is absolute
-cd $top_srcdir; top_srcdir=`pwd`
+top_srcdir=`cd $top_srcdir; pwd`
 
 STAT_CONFIG_PATH=$top_srcdir/config
 export STAT_CONFIG_PATH
 
+LANG=C
+export LANG
+
 
 cleanup()
 {
+     if [ x"$PSPP_TEST_NO_CLEANUP" != x ] ; then 
+	echo "NOT cleaning $TEMPDIR" 
+	return ; 
+     fi
      cd /
      rm -rf $TEMPDIR
-     :
 }
 
 
@@ -71,12 +81,13 @@ EOF
 if [ $? -ne 0 ] ; then no_result; fi
 
 activity="run program $i"
-$SUPERVISOR $here/../src/pspp -o raw-ascii $TEMPDIR/prog.sps
+$SUPERVISOR $PSPP --testing-mode $TEMPDIR/prog.sps
 if [ $? -ne 0 ] ; then no_result ; fi
 
 activity="compare output $i"
-diff -B -b $TEMPDIR/pspp.list - <<EOF
-1.1 FREQUENCIES.  X: 
+perl -pi -e 's/^\s*$//g' $TEMPDIR/pspp.list
+diff  -b $TEMPDIR/pspp.list - <<EOF
+1.1 FREQUENCIES.  X 
 +-----------+--------+---------+--------+--------+--------+
 |           |        |         |        |  Valid |   Cum  |
 |Value Label|  Value |Frequency| Percent| Percent| Percent|
@@ -89,20 +100,19 @@ diff -B -b $TEMPDIR/pspp.list - <<EOF
 #===========#========#=========#========#========#========#
 |               Total|        5|   100.0|   100.0|        |
 +--------------------+---------+--------+--------+--------+
-
-+-------------------+-----+
-|N           Valid  |    5|
-|            Missing|    0|
-|Mean               |3.000|
-|Std Dev            |1.581|
-|Minimum            |1.000|
-|Maximum            |5.000|
-|Percentiles 0      |1.000|
-|            25     |2.000|
-|            50     |3.000|
-|            75     |4.000|
-|            100    |5.000|
-+-------------------+-----+
++-----------------------+-----+
+|N           Valid      |    5|
+|            Missing    |    0|
+|Mean                   |3.000|
+|Std Dev                |1.581|
+|Minimum                |1.000|
+|Maximum                |5.000|
+|Percentiles 0          |1.000|
+|            25         |2.000|
+|            50 (Median)|3.000|
+|            75         |4.000|
+|            100        |5.000|
++-----------------------+-----+
 EOF
 if [ $? -ne 0 ] ; then fail ; fi
 
@@ -134,12 +144,13 @@ if [ $? -ne 0 ] ; then no_result; fi
 
 
 activity="run program $i"
-$SUPERVISOR $here/../src/pspp -o raw-ascii $TEMPDIR/prog.sps
+$SUPERVISOR $PSPP --testing-mode $TEMPDIR/prog.sps
 if [ $? -ne 0 ] ; then no_result ; fi
 
 activity="compare output $i"
-diff -B -b $TEMPDIR/pspp.list - <<EOF
-1.1 FREQUENCIES.  X: 
+perl -pi -e 's/^\s*$//g' $TEMPDIR/pspp.list
+diff  -b $TEMPDIR/pspp.list - <<EOF
+1.1 FREQUENCIES.  X 
 +-----------+--------+---------+--------+--------+--------+
 |           |        |         |        |  Valid |   Cum  |
 |Value Label|  Value |Frequency| Percent| Percent| Percent|
@@ -152,20 +163,19 @@ diff -B -b $TEMPDIR/pspp.list - <<EOF
 #===========#========#=========#========#========#========#
 |               Total|       10|   100.0|   100.0|        |
 +--------------------+---------+--------+--------+--------+
-
-+-------------------+-----+
-|N           Valid  |   10|
-|            Missing|    0|
-|Mean               |3.000|
-|Std Dev            |1.491|
-|Minimum            |1.000|
-|Maximum            |5.000|
-|Percentiles 0      |1.000|
-|            25     |2.000|
-|            50     |3.000|
-|            75     |4.000|
-|            100    |5.000|
-+-------------------+-----+
++-----------------------+-----+
+|N           Valid      |   10|
+|            Missing    |    0|
+|Mean                   |3.000|
+|Std Dev                |1.491|
+|Minimum                |1.000|
+|Maximum                |5.000|
+|Percentiles 0          |1.000|
+|            25         |2.000|
+|            50 (Median)|3.000|
+|            75         |4.000|
+|            100        |5.000|
++-----------------------+-----+
 EOF
 if [ $? -ne 0 ] ; then fail ; fi
 
@@ -195,12 +205,13 @@ if [ $? -ne 0 ] ; then no_result; fi
 
 
 activity="run program $i"
-$SUPERVISOR $here/../src/pspp -o raw-ascii $TEMPDIR/prog.sps
+$SUPERVISOR $PSPP --testing-mode $TEMPDIR/prog.sps
 if [ $? -ne 0 ] ; then no_result ; fi
 
 activity="compare output $i"
-diff -B -b $TEMPDIR/pspp.list - <<EOF
-1.1 FREQUENCIES.  X: 
+perl -pi -e 's/^\s*$//g' $TEMPDIR/pspp.list
+diff  -b $TEMPDIR/pspp.list - <<EOF
+1.1 FREQUENCIES.  X 
 +-----------+--------+---------+--------+--------+--------+
 |           |        |         |        |  Valid |   Cum  |
 |Value Label|  Value |Frequency| Percent| Percent| Percent|
@@ -212,20 +223,19 @@ diff -B -b $TEMPDIR/pspp.list - <<EOF
 #===========#========#=========#========#========#========#
 |               Total|        6|   100.0|   100.0|        |
 +--------------------+---------+--------+--------+--------+
-
-+-------------------+-----+
-|N           Valid  |    6|
-|            Missing|    0|
-|Mean               |3.500|
-|Std Dev            |1.517|
-|Minimum            |1.000|
-|Maximum            |5.000|
-|Percentiles 0      |1.000|
-|            25     |3.000|
-|            50     |3.500|
-|            75     |4.750|
-|            100    |5.000|
-+-------------------+-----+
++-----------------------+-----+
+|N           Valid      |    6|
+|            Missing    |    0|
+|Mean                   |3.500|
+|Std Dev                |1.517|
+|Minimum                |1.000|
+|Maximum                |5.000|
+|Percentiles 0          |1.000|
+|            25         |3.000|
+|            50 (Median)|3.500|
+|            75         |4.750|
+|            100        |5.000|
++-----------------------+-----+
 EOF
 if [ $? -ne 0 ] ; then fail ; fi
 
@@ -255,12 +265,13 @@ if [ $? -ne 0 ] ; then no_result; fi
 
 
 activity="run program $i"
-$SUPERVISOR $here/../src/pspp -o raw-ascii $TEMPDIR/prog.sps
+$SUPERVISOR $PSPP --testing-mode $TEMPDIR/prog.sps
 if [ $? -ne 0 ] ; then no_result ; fi
 
 activity="compare output $i"
-diff -B -b $TEMPDIR/pspp.list - <<EOF
-1.1 FREQUENCIES.  X: 
+perl -pi -e 's/^\s*$//g' $TEMPDIR/pspp.list
+diff -b $TEMPDIR/pspp.list - <<EOF
+1.1 FREQUENCIES.  X 
 +-----------+--------+---------+--------+--------+--------+
 |           |        |         |        |  Valid |   Cum  |
 |Value Label|  Value |Frequency| Percent| Percent| Percent|
@@ -273,20 +284,19 @@ diff -B -b $TEMPDIR/pspp.list - <<EOF
 #===========#========#=========#========#========#========#
 |               Total|       10|   100.0|   100.0|        |
 +--------------------+---------+--------+--------+--------+
-
-+-------------------+-----+
-|N           Valid  |    6|
-|            Missing|    4|
-|Mean               |3.500|
-|Std Dev            |1.517|
-|Minimum            |1.000|
-|Maximum            |5.000|
-|Percentiles 0      |1.000|
-|            25     |3.000|
-|            50     |3.500|
-|            75     |4.750|
-|            100    |5.000|
-+-------------------+-----+
++-----------------------+-----+
+|N           Valid      |    6|
+|            Missing    |    4|
+|Mean                   |3.500|
+|Std Dev                |1.517|
+|Minimum                |1.000|
+|Maximum                |5.000|
+|Percentiles 0          |1.000|
+|            25         |3.000|
+|            50 (Median)|3.500|
+|            75         |4.750|
+|            100        |5.000|
++-----------------------+-----+
 EOF
 if [ $? -ne 0 ] ; then fail ; fi
 
